==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ksf.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ksf extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "m\u0254ni m\u01dd \u00e1 b\u01ddl\u0254\u014b b\u01dd kaksa b\u025b t\u00e1at\u00e1a\u014bz\u01ddn" },
            { "aoa", "m\u0254ni m\u01dd \u00e1 ang\u00f3la" },
            { "aud", "m\u0254ni m\u01dd \u00e1 \u0254stral\u00ed" },
            { "bhd", "m\u0254ni m\u01dd \u00e1 bar\u01dd\u0301n" },
            { "bif", "m\u0254ni m\u01dd \u00e1 burund\u00ed" },
            { "bwp", "m\u0254ni m\u01dd \u00e1 botswana" },
            { "cad", "m\u0254ni m\u01dd \u00e1 kanada" },
            { "cdf", "m\u0254ni m\u01dd \u00e1 k\u0254ng\u00f3" },
            { "chf", "m\u0254ni m\u01dd \u00e1 sw\u00eds" },
            { "cny", "m\u0254ni m\u01dd \u00e1 c\u00edn" },
            { "cve", "m\u0254ni m\u01dd \u00e1 kapv\u025br" },
            { "djf", "m\u0254ni m\u01dd \u00e1 dyibut\u00ed" },
            { "dzd", "m\u0254ni m\u01dd \u00e1 alj\u025br\u00ed" },
            { "egp", "m\u0254ni m\u01dd \u00e1 \u025bj\u00edpt" },
            { "ern", "m\u0254ni m\u01dd \u00e1 \u025britr\u025b\u0301" },
            { "etb", "m\u0254ni m\u01dd \u00e1 \u025bty\u0254p\u00ed" },
            { "eur", "m\u0254ni m\u01dd \u00e1 p\u025br\u025bs\u01dd\u0301" },
            { "gbp", "m\u0254ni m\u01dd \u00e1 ing\u025br\u00eds" },
            { "ghc", "m\u0254ni m\u01dd \u00e1 g\u00e1na" },
            { "gmd", "m\u0254ni m\u01dd \u00e1 gamb\u00ed" },
            { "gns", "m\u0254ni m\u01dd \u00e1 gin\u025b\u0301" },
            { "inr", "m\u0254ni m\u01dd \u00e1 ind\u00ed" },
            { "jpy", "m\u0254ni m\u01dd \u00e1 jap\u0254\u0301\u014b" },
            { "kes", "m\u0254ni m\u01dd \u00e1 k\u025bnya" },
            { "kmf", "m\u0254ni m\u01dd \u00e1 kom\u0254r" },
            { "lrd", "m\u0254ni m\u01dd \u00e1 lib\u025brya" },
            { "lsl", "m\u0254ni m\u01dd \u00e1 l\u01dds\u00f3to" },
            { "lyd", "m\u0254ni m\u01dd \u00e1 lib\u00ed" },
            { "mad", "m\u0254ni m\u01dd \u00e1 mar\u0254k" },
            { "mga", "m\u0254ni m\u01dd \u00e1 madagaska" },
            { "mro", "m\u0254ni m\u01dd \u00e1 mwaritan\u00ed (1973\u20132017)" },
            { "mru", "m\u0254ni m\u01dd \u00e1 mwaritan\u00ed" },
            { "mur", "m\u0254ni m\u01dd \u00e1 mwar\u00eds" },
            { "mwk", "m\u0254ni m\u01dd \u00e1 malawi" },
            { "mzm", "m\u0254ni m\u01dd \u00e1 mosamb\u00edk" },
            { "nad", "m\u0254ni m\u01dd \u00e1 namib\u00ed" },
            { "ngn", "m\u0254ni m\u01dd \u00e1 nij\u025b\u0301rya" },
            { "rwf", "m\u0254ni m\u01dd \u00e1 rwanda" },
            { "sar", "m\u0254ni m\u01dd \u00e1 arab\u00ed saod\u00ed" },
            { "scr", "m\u0254ni m\u01dd \u00e1 s\u025bc\u025bl" },
            { "sdg", "m\u0254ni m\u01dd \u00e1 sudan" },
            { "shp", "m\u0254ni m\u01dd \u00e1 s\u025bnt\u025b\u0301len" },
            { "sll", "m\u0254ni m\u01dd \u00e1 sy\u025braleon" },
            { "sos", "m\u0254ni m\u01dd \u00e1 somal\u00ed" },
            { "std", "m\u0254ni m\u01dd \u00e1 saotom\u025b\u0301 ri pri\u014bsib (1977\u20132017)" },
            { "stn", "m\u0254ni m\u01dd \u00e1 saotom\u025b\u0301 ri pri\u014bsib" },
            { "szl", "m\u0254ni m\u01dd \u00e1 swazilan" },
            { "tnd", "m\u0254ni m\u01dd \u00e1 tun\u025bs\u00ed" },
            { "tzs", "m\u0254ni m\u01dd \u00e1 tanzan\u00ed" },
            { "ugx", "m\u0254ni m\u01dd \u00e1 uganda" },
            { "usd", "m\u0254ni m\u01dd \u00e1 am\u025brika" },
            { "xaf", "fr\u00e1\u014b" },
            { "xof", "m\u0254ni m\u01dd \u00e1 afr\u00edka an\u00e1 w\u025bs" },
            { "zar", "m\u0254ni m\u01dd \u00e1 afrik an\u01dd a sud" },
            { "zmk", "m\u0254ni m\u01dd \u00e1 zamb\u00ed (1968\u20132012)" },
            { "zmw", "m\u0254ni m\u01dd \u00e1 zamb\u00ed" },
            { "zwd", "m\u0254ni m\u01dd \u00e1 zimbabw\u025b\u0301" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1.1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ksf.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ksf extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "m\u0254ni m\u01dd \u00e1 b\u01ddl\u0254\u014b b\u01dd kaksa b\u025b t\u00e1at\u00e1a\u014bz\u01ddn" },
            { "aoa", "m\u0254ni m\u01dd \u00e1 ang\u00f3la" },
            { "aud", "m\u0254ni m\u01dd \u00e1 \u0254stral\u00ed" },
            { "bhd", "m\u0254ni m\u01dd \u00e1 bar\u01dd\u0301n" },
            { "bif", "m\u0254ni m\u01dd \u00e1 burund\u00ed" },
            { "bwp", "m\u0254ni m\u01dd \u00e1 botswana" },
            { "cad", "m\u0254ni m\u01dd \u00e1 kanada" },
            { "cdf", "m\u0254ni m\u01dd \u00e1 k\u0254ng\u00f3" },
            { "chf", "m\u0254ni m\u01dd \u00e1 sw\u00eds" },
            { "cny", "m\u0254ni m\u01dd \u00e1 c\u00edn" },
            { "cve", "m\u0254ni m\u01dd \u00e1 kapv\u025br" },
            { "djf", "m\u0254ni m\u01dd \u00e1 dyibut\u00ed" },
            { "dzd", "m\u0254ni m\u01dd \u00e1 alj\u025br\u00ed" },
            { "egp", "m\u0254ni m\u01dd \u00e1 \u025bj\u00edpt" },
            { "ern", "m\u0254ni m\u01dd \u00e1 \u025britr\u025b\u0301" },
            { "etb", "m\u0254ni m\u01dd \u00e1 \u025bty\u0254p\u00ed" },
            { "eur", "m\u0254ni m\u01dd \u00e1 p\u025br\u025bs\u01dd\u0301" },
            { "gbp", "m\u0254ni m\u01dd \u00e1 ing\u025br\u00eds" },
            { "ghc", "m\u0254ni m\u01dd \u00e1 g\u00e1na" },
            { "gmd", "m\u0254ni m\u01dd \u00e1 gamb\u00ed" },
            { "gns", "m\u0254ni m\u01dd \u00e1 gin\u025b\u0301" },
            { "inr", "m\u0254ni m\u01dd \u00e1 ind\u00ed" },
            { "jpy", "m\u0254ni m\u01dd \u00e1 jap\u0254\u0301\u014b" },
            { "kes", "m\u0254ni m\u01dd \u00e1 k\u025bnya" },
            { "kmf", "m\u0254ni m\u01dd \u00e1 kom\u0254r" },
            { "lrd", "m\u0254ni m\u01dd \u00e1 lib\u025brya" },
            { "lsl", "m\u0254ni m\u01dd \u00e1 l\u01dds\u00f3to" },
            { "lyd", "m\u0254ni m\u01dd \u00e1 lib\u00ed" },
            { "mad", "m\u0254ni m\u01dd \u00e1 mar\u0254k" },
            { "mga", "m\u0254ni m\u01dd \u00e1 madagaska" },
            { "mro", "m\u0254ni m\u01dd \u00e1 mwaritan\u00ed (1973\u20132017)" },
            { "mru", "m\u0254ni m\u01dd \u00e1 mwaritan\u00ed" },
            { "mur", "m\u0254ni m\u01dd \u00e1 mwar\u00eds" },
            { "mwk", "m\u0254ni m\u01dd \u00e1 malawi" },
            { "mzm", "m\u0254ni m\u01dd \u00e1 mosamb\u00edk" },
            { "nad", "m\u0254ni m\u01dd \u00e1 namib\u00ed" },
            { "ngn", "m\u0254ni m\u01dd \u00e1 nij\u025b\u0301rya" },
            { "rwf", "m\u0254ni m\u01dd \u00e1 rwanda" },
            { "sar", "m\u0254ni m\u01dd \u00e1 arab\u00ed saod\u00ed" },
            { "scr", "m\u0254ni m\u01dd \u00e1 s\u025bc\u025bl" },
            { "sdg", "m\u0254ni m\u01dd \u00e1 sudan" },
            { "shp", "m\u0254ni m\u01dd \u00e1 s\u025bnt\u025b\u0301len" },
            { "sle", "m\u0254ni m\u01dd \u00e1 sy\u025braleon" },
            { "sll", "m\u0254ni m\u01dd \u00e1 sy\u025braleon (1964\u20142022)" },
            { "sos", "m\u0254ni m\u01dd \u00e1 somal\u00ed" },
            { "std", "m\u0254ni m\u01dd \u00e1 saotom\u025b\u0301 ri pri\u014bsib (1977\u20132017)" },
            { "stn", "m\u0254ni m\u01dd \u00e1 saotom\u025b\u0301 ri pri\u014bsib" },
            { "szl", "m\u0254ni m\u01dd \u00e1 swazilan" },
            { "tnd", "m\u0254ni m\u01dd \u00e1 tun\u025bs\u00ed" },
            { "tzs", "m\u0254ni m\u01dd \u00e1 tanzan\u00ed" },
            { "ugx", "m\u0254ni m\u01dd \u00e1 uganda" },
            { "usd", "m\u0254ni m\u01dd \u00e1 am\u025brika" },
            { "xaf", "fr\u00e1\u014b" },
            { "xof", "m\u0254ni m\u01dd \u00e1 afr\u00edka an\u00e1 w\u025bs" },
            { "zar", "m\u0254ni m\u01dd \u00e1 afrik an\u01dd a sud" },
            { "zmk", "m\u0254ni m\u01dd \u00e1 zamb\u00ed (1968\u20132012)" },
            { "zmw", "m\u0254ni m\u01dd \u00e1 zamb\u00ed" },
            { "zwd", "m\u0254ni m\u01dd \u00e1 zimbabw\u025b\u0301" },
        };
        return data;
    }
}
